/*
 * Copyright (c) 1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *
 * 4. The names "Java Apache Element Construction Set", "Java Apache ECS" and 
 *    "Java Apache Project" must not be used to endorse or promote products 
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called 
 *    "Java Apache Element Construction Set" nor "Java Apache ECS" appear 
 *    in their names without prior written permission of the 
 *    Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *    
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Project. For more information
 * on the Java Apache Project please see <http://java.apache.org/>.
 *
 */
package org.apache.ecs.html;

import org.apache.ecs.*;

/**
    This class creates a &lt;TEXTAREA&gt;&lt;/TEXTAREA&gt; tag.

    @version $Id: TextArea.java,v 1.1.1.1 1999/06/22 02:15:12 jonbolt Exp $
    @author <a href="mailto:snagy@servletapi.com">Stephan Nagy</a>
    @author <a href="mailto:jon@clearink.com">Jon S. Stevens</a>
*/
public class TextArea extends MultiPartElement
{
    public final static String OFF = "off";
    public final static String PHYSICAL = "physical";
    public final static String VIRTUAL = "virtual";
    
    /**
        Private initializer.
    */
    {
        setElementType("textarea");
    }
    /**
        Basic Constructor use set* methods.
    */
    public TextArea()
    {
    }

    /**
        Basic Constructor use set* methods.
        @param rows  the ROWS="" attribute
        @param cols  the COLS="" attribute
    */
    public TextArea(int rows, int cols)
    {
        setRows(rows);
        setCols(cols);
    }
    
    /**
        Basic Constructor use set* methods.
        @param rows  the ROWS="" attribute
        @param cols  the COLS="" attribute
    */
    public TextArea(String rows, String cols)
    {
        setRows(rows);
        setCols(cols);
    }
    
    /**
        Basic Constructor use set* methods.
        @param name  the NAME="" attribute
        @param rows  the ROWS="" attribute
        @param cols  the COLS="" attribute
    */
    public TextArea(String name, int rows, int cols)
    {
        setName(name);
        setRows(rows);
        setCols(cols);
    }
    
    /**
        Basic Constructor use set* methods.
        @param name  the NAME="" attribute
        @param rows  the ROWS="" attribute
        @param cols  the COLS="" attribute
    */
    public TextArea(String name, String rows, String cols)
    {
        setName(name);
        setRows(rows);
        setCols(cols);
    }
    
    /**
        Sets the ROWS="" attribute
        @param  rows   Sets the ROWS="" attribute
    */
    public TextArea setRows(int rows)
    {
        setRows(Integer.toString(rows));
        return(this);
    }

    /**
        Sets the ROWS="" attribute
        @param  rows   Sets the ROWS="" attribute
    */
    public TextArea setRows(String rows)
    {
        addAttribute("rows",rows);
        return(this);
    }

    /**
        Sets the WRAP="" attribute
        @param  wrap   Sets the WRAP="" attribute
    */
    public TextArea setWrap(String wrap)
    {
        addAttribute("wrap",wrap);
        return(this);
    }

    /**
        Sets the COLS="" attribute
        @param  cols   Sets the COLS="" attribute
    */
    public TextArea setCols(int cols)
    {
        setCols(Integer.toString(cols));
        return(this);
    }

    /**
        Sets the COLS="" attribute
        @param  cols   Sets the COLS="" attribute
    */
    public TextArea setCols(String cols)
    {
        addAttribute("cols",cols);
        return(this);
    }

    /**
        Sets the NAME="" attribute
        @param  name   Sets the NAME="" attribute
    */
    public TextArea setName(String name)
    {
        addAttribute("name",name);
        return(this);
    }

    /**
        Sets the TABINDEX="" attribute
        @param   alt  the TABINDEX="" attribute
    */
    public TextArea setTabindex(String index)
    {
        addAttribute("tabindex",index);
        return this;
    }
    
    /**
        Sets the TABINDEX="" attribute
        @param   alt  the TABINDEX="" attribute
    */
    public TextArea setTabindex(int index)
    {
        setTabindex(Integer.toString(index));
        return this;
    }
    
    /**
        Sets the readonly value
        @param   readonly  true or false
    */
    public TextArea setReadOnly(boolean readonly)
    {
        if ( readonly == true )
            addAttribute("readonly", NO_ATTRIBUTE_VALUE);
        else
            removeAttribute("readonly");
            
        return(this);
    }

    /**
        Sets the disabled value
        @param   disabled  true or false
    */
    public TextArea setDisabled(boolean disabled)
    {
        if ( disabled == true )
            addAttribute("disabled", NO_ATTRIBUTE_VALUE);
        else
            removeAttribute("disabled");
            
        return(this);
    }
    
    /**
        Adds an Element to the element.
        @param  hashcode name of element for hash table
        @param  element Adds an Element to the element.
     */
    public TextArea addElement(String hashcode,Element element)
    {
        addElementToRegistry(hashcode,element);
        return(this);
    }

    /**
        Adds an Element to the element.
        @param  hashcode name of element for hash table
        @param  element Adds an Element to the element.
     */
    public TextArea addElement(String hashcode,String element)
    {
        addElementToRegistry(hashcode,element);
        return(this);
    }

    /**
        Adds an Element to the element.
        @param  element Adds an Element to the element.
     */
    public TextArea addElement(Element element)
    {
        addElementToRegistry(element);
        return(this);
    }

    /**
        Adds an Element to the element.
        @param  element Adds an Element to the element.
     */
    public TextArea addElement(String element)
    {
        addElementToRegistry(element);
        return(this);
    }
    /**
        Removes an Element from the element.
        @param hashcode the name of the element to be removed.
    */
    public TextArea removeElement(String hashcode)
    {
        removeElementFromRegistry(hashcode);
        return(this);
    }
} 